/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.refactoring.openapi.impl;

import com.intellij.openapi.project.Project;
import com.intellij.psi.PsiClass;
import com.intellij.psi.PsiField;
import com.intellij.refactoring.MakeStaticRefactoring;
import com.intellij.refactoring.RefactoringImpl;
import com.intellij.refactoring.makeStatic.MakeClassStaticProcessor;
import com.intellij.refactoring.makeStatic.Settings;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

public class MakeClassStaticRefactoringImpl extends RefactoringImpl<MakeClassStaticProcessor>
  implements MakeStaticRefactoring<PsiClass> {
  MakeClassStaticRefactoringImpl(Project project,
                                 PsiClass aClass,
                                 boolean replaceUsages,
                                 String classParameterName,
                                 PsiField[] fields,
                                 String[] names) {
    super(new MakeClassStaticProcessor(project, aClass, new Settings(replaceUsages, classParameterName, fields, names)));
  }

  @Override
  public PsiClass getMember() {
    return myProcessor.getMember();
  }

  @Override
  public boolean isReplaceUsages() {
    return myProcessor.getSettings().isReplaceUsages();
  }

  @Override
  public String getClassParameterName() {
    return myProcessor.getSettings().getClassParameterName();
  }

  @Override
  public List<PsiField> getFields() {
    final Settings settings = myProcessor.getSettings();
    List<PsiField> result = new ArrayList<>();
    final List<Settings.FieldParameter> parameterOrderList = settings.getParameterOrderList();
    for (final Settings.FieldParameter fieldParameter : parameterOrderList) {
      result.add(fieldParameter.field);
    }

    return result;
  }

  @Override
  @Nullable
  public String getParameterNameForField(PsiField field) {
    return myProcessor.getSettings().getNameForField(field);
  }
}
